package com.huimv.env.admin.controller;


import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huimv.env.admin.entity.ArrangeList;
import com.huimv.env.admin.service.IArrangeListService;
import com.huimv.env.common.utils.Result;
import com.huimv.env.common.utils.ResultCode;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;

import org.springframework.web.bind.annotation.RestController;

import java.util.Map;

/**
 * <p>
 * 前端控制器
 * </p>
 *
 * @author author
 * @since 2023-10-24
 */
@RestController
@RequestMapping("/arrange-list")
@CrossOrigin
public class ArrangeListController {

    @Autowired
    private IArrangeListService arrangeListService;

    @RequestMapping("/list")
    public Result list(@RequestBody Map<String, String> paramsMap) {
        String mac = paramsMap.get("macAddress");
        String disk = paramsMap.get("diskAddress");
        String ipAddr = paramsMap.get("ipAddress");

        String pageNum = paramsMap.get("pageNum");
        String pageSize = paramsMap.get("pageSize");

        QueryWrapper<ArrangeList> queryWrapper = new QueryWrapper<>();
        queryWrapper.like(StringUtils.isNotBlank(mac), "mac_address", mac);
        queryWrapper.like(StringUtils.isNotBlank(disk), "disk_address", disk);
        queryWrapper.like(StringUtils.isNotBlank(ipAddr), "ip_address", ipAddr);

        if (null == pageNum || "".equals(pageNum)) {
            pageNum = "1";
        }
        if (null == pageSize || "".equals(pageSize)) {
            pageSize = "10";
        }

        Page<ArrangeList> page = new Page<>(Integer.parseInt(pageNum), Integer.parseInt(pageSize));
        Page<ArrangeList> listPage = arrangeListService.page(page, queryWrapper);

        return new Result(ResultCode.SUCCESS, listPage);
    }

    @RequestMapping("/delete")
    public Result delete(@RequestBody Map<String, String> paramsMap) {
        String id = paramsMap.get("id");
        arrangeListService.removeById(id);
        return new Result(10000, "删除成功！", true);
    }

    @RequestMapping("/edit")
    public Result edit(@RequestBody ArrangeList arrangeList) {
        QueryWrapper<ArrangeList> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("mac_address", arrangeList.getMacAddress()).ne("id", arrangeList.getId());
        ArrangeList one = arrangeListService.getOne(queryWrapper);
        if (ObjectUtil.isNotEmpty(one)) {
            return new Result(10001, "修改失败，mac地址已存在", false);
        }
        QueryWrapper<ArrangeList> queryWrapper1 = new QueryWrapper<>();
        queryWrapper1.eq("disk_address", arrangeList.getDiskAddress()).ne("id", arrangeList.getId());
        ArrangeList one1 = arrangeListService.getOne(queryWrapper1);
        if (ObjectUtil.isNotEmpty(one1)) {
            return new Result(10001, "修改失败，硬盘地址已存在", false);
        }
        arrangeListService.updateById(arrangeList);
        return new Result(10000, "修改成功！", true);
    }

    @RequestMapping("/add")
    public Result add(@RequestBody ArrangeList arrangeList) {
        QueryWrapper<ArrangeList> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("mac_address", arrangeList.getMacAddress()).or().eq("disk_address", arrangeList.getDiskAddress());
        ArrangeList one = arrangeListService.getOne(queryWrapper);
        if (ObjectUtil.isNotEmpty(one)) {
            return new Result(10001, "添加失败，mac地址或者硬盘已存在", false);
        }
        arrangeListService.save(arrangeList);
        return new Result(10000, "添加成功！", true);
    }

    @RequestMapping("/find")
    public Result find(@RequestBody Map<String, String> paramsMap) {
        String mac = paramsMap.get("macAddress");
        String disk = paramsMap.get("diskAddress");
        String ipAddr = paramsMap.get("ipAddress");
        QueryWrapper<ArrangeList> queryWrapper = new QueryWrapper<>();
        queryWrapper.like(StringUtils.isNotBlank(mac), "mac_address", mac)
                .or().like(StringUtils.isNotBlank(disk), "disk_address", disk)
                .or().like(StringUtils.isNotBlank(ipAddr), "ip_address", ipAddr);
        ArrangeList arrangeList = arrangeListService.getOne(queryWrapper);
        return new Result(ResultCode.SUCCESS, arrangeList);
    }
}
